@@ -1,6 +1,6 @@
 // SPDX-FileCopyrightText: 2009 Volker Krause <vkrause@kde.org>
 // SPDX-FileCopyrightText: 2023 Carl Schwan <carl@carlschwan.eu>
-// SPDX-FileCopyrightText: 2023-2024 Laurent Montel <montel.org>
+// SPDX-FileCopyrightText: 2023-2025 Laurent Montel <montel@kde.org>
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
 #include <Akonadi/Control>
@@ -9,47 +9,38 @@
 #include <KDBusService>
 #include <KLocalizedString>
 
+#include <KIconTheme>
+#include <KLocalizedQmlContext>
 #include <QApplication>
 #include <QCommandLineParser>
 #include <QDebug>
 #include <QIcon>
 #include <QQmlApplicationEngine>
 #include <QQmlContext>
-#if KI18N_VERSION >= QT_VERSION_CHECK(6, 8, 0)
-#include <KLocalizedQmlContext>
-#endif
-#define HAVE_KICONTHEME __has_include(<KIconTheme>)
-#if HAVE_KICONTHEME
-#include <KIconTheme>
-#endif
+#include <QQuickStyle>
 
-#define HAVE_STYLE_MANAGER __has_include(<KStyleManager>)
-#if HAVE_STYLE_MANAGER
 #include <KStyleManager>
-#endif
 using namespace Qt::Literals::StringLiterals;
 
 int main(int argc, char **argv)
 {
-#if HAVE_KICONTHEME
     KIconTheme::initTheme();
-#endif
     QCoreApplication::setAttribute(Qt::AA_ShareOpenGLContexts);
     QApplication app(argc, argv);
     KLocalizedString::setApplicationDomain(QByteArrayLiteral("accountwizard"));
-#if HAVE_STYLE_MANAGER
+
+    // Default to org.kde.desktop style unless the user forces another style
+    if (qEnvironmentVariableIsEmpty("QT_QUICK_CONTROLS_STYLE")) {
+        QQuickStyle::setStyle(QStringLiteral("org.kde.desktop"));
+    }
+
     KStyleManager::initStyle();
-#else // !HAVE_STYLE_MANAGER
-#if defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-    QApplication::setStyle(QStringLiteral("breeze"));
-#endif // defined(Q_OS_MACOS) || defined(Q_OS_WIN)
-#endif // HAVE_STYLE_MANAGER
     KAboutData aboutData(QStringLiteral("accountwizard"),
                          i18n("Account Assistant"),
                          QStringLiteral("0.3"),
                          i18n("Helps setting up PIM accounts"),
                          KAboutLicense::LGPL,
-                         i18n("(c) 2009-2024 the Akonadi developers"),
+                         i18n("(c) 2009-2025 the Akonadi developers"),
                          QString(),
                          QStringLiteral("https://community.kde.org/KDE_PIM/Akonadi"));
     aboutData.addAuthor(i18nc("@info:credit", "Volker Krause"), i18n("Author"), QStringLiteral("vkrause@kde.org"));
@@ -74,11 +65,7 @@ int main(int argc, char **argv)
 
     QQmlApplicationEngine engine;
 
-#if KI18N_VERSION < QT_VERSION_CHECK(6, 8, 0)
-    engine.rootContext()->setContextObject(new KLocalizedContext(&engine));
-#else
     engine.rootContext()->setContextObject(new KLocalizedQmlContext(&engine));
-#endif
 
     engine.loadFromModule("org.kde.pim.accountwizard", "Main");
 
